#!/bin/sh

is_redis_password_written_in_conf()
{
    if grep -q "^\s*requirepass " $redis_conf; then
        # 0 means true
        return 0 
    fi
    # 1 means false
    return 1
}

add_redis_password_in_conf()
{
    local password=$1
    echo "requirepass $password" >> $redis_conf
}

update_redis_password_in_conf()
{
    local password=$1
    sudo sed -i "s/^\s*requirepass \+.\+$/requirepass $password/g"  $redis_conf
}

update_key_in_db_config_yml()
{
    local key=$1
    local value=$2
    local conf_util='/opt/cyops/configs/scripts/confUtil.py'
    local cyops_db_conn_file='/opt/cyops/configs/database/db_config.yml'
    local cmd="$conf_util --file=$cyops_db_conn_file -k=$key -v=$value"
    $cmd
}

update_redis_password_in_db_config_yml()
{
    local password=$1
    update_key_in_db_config_yml 'redis_password' $password
    update_key_in_db_config_yml 'redis_password_primary' $password
}

get_redis_password()
{
    das_ini='/opt/cyops-auth/utilities/das.ini'

    # following command do:
    # 1. Find the block [CLUSTER] from das.ini
    # grep for line starting with nodeid
    # cut the line on = and get field 2. i.e nodeid/password 
    # left and right trim the string to remove the trailing spaces

    local password=`sed -n '/\[CLUSTER\]/,/\[\?/p' $das_ini | grep "^\s*nodeid \+=" | cut -d'=' -f2 | awk '{$1=$1};1'`
    echo $password
}

get_encrypted_password()
{
    local plain_pass=$1
    encrypted_pass=`/opt/cyops/configs/scripts/manage_passwords.py --encrypt $plain_pass`
    echo $encrypted_pass
}

#####
#  MAIN program starts here
###

redis_conf='/etc/redis.conf'

if [ ! -f $redis_conf ]; then
    echo "File not found: [$redis_conf]"
    exit 1
fi

password=`get_redis_password`

if [ "X$password" = "X" ]; then
    echo "Failed to get the password. Exiting..."
    exit 1
fi

if ! is_redis_password_written_in_conf; then
    add_redis_password_in_conf $password 
else
    update_redis_password_in_conf $password
fi

encrypted_pass=`get_encrypted_password $password`

update_redis_password_in_db_config_yml $encrypted_pass

exit 0
