
import tornado.ioloop
import tornado.web
from tornado.httpserver import HTTPServer
import ssl
import sys
import os
import OpenSSL
from subprocess import check_call
import signal

server = None

pid = None

class CSDASSRV:

    @staticmethod
    def shutdown():
        """
        The function is designed to kill this service, if it's running.  it does this by calling getpid()
        to get the current pid from the database. if a pid is returned, it's killed with a SIGTERM signal,
        terminating the service immediately.
        @return:
        """
        global server
        if server is not None:
            server.stop()
        tornado.ioloop.IOLoop.current().stop()
        try:
            if pid:
                os.kill(pid, signal.SIGTERM)
        except ProcessLookupError as error:
            pass
        check_call(['pkill', '-f', 'csdassrv.py'])
        exit(0)

    @staticmethod
    def start():
        """
        This function starts the csdassrv service.  In addtion to that, it also saves the
        active process id (pid) to the database, so the service can be shutdown programmatically.
        @return: None
        """
        from handlers import (
            apikeyshandler,
            usershandler,
            tokenhandler,
            ldaphandler,
            authenticationhandler,
            nfahandler,
            eventhandler,
            confighandler,
            licensehandler,
            passwordhandler,
            clusterhandler,
        )
        from utilities.propsmgr import PropertiesManager
        from utilities import cspropconstants as csp

        app = tornado.web.Application([
            (r"/apikeys/?", apikeyshandler.APIKeysHandler),
            (r"/users/?", usershandler.UsersHandler),
            (r"/authenticate/?", authenticationhandler.AuthenticateHandler),
            (r"/nfa/?", nfahandler.NFAHandler),
            (r"/event/?", eventhandler.EventsHandler),
            (r"/config/?", confighandler.ConfigHandler),
            (r"/token/?", tokenhandler.TokenHandler),
            (r"/ldap/?", ldaphandler.LDAPHandler),
            (r"/license/?", licensehandler.LicenseHandler),
            (r"/token/(?P<jti>[^\/]+)/?", tokenhandler.TokenHandler),
            (r"/password/?", passwordhandler.PasswordHandler),
            (r"/cluster/?", clusterhandler.ClusterHandler),
            (r"/clusteroperation/?", clusterhandler.HAHandler),
            (r"/clusteroperation/(?P<id>[^\/]+)/?", clusterhandler.HAHandler),
            (r"/clustercommand/?", clusterhandler.ClusterCommandHandler),
            (r"/clustercommand/(?P<id>[^\/]+)/?", clusterhandler.ClusterCommandHandler),
        ], static_path=os.path.join(os.path.dirname(__file__), '..', "static"))

        sslctx = ssl.SSLContext(ssl.PROTOCOL_TLS)
        sslctx.options |= ssl.OP_NO_SSLv2
        sslctx.options |= ssl.OP_NO_SSLv3
        sslctx.options |= ssl.OP_NO_TLSv1
        sslctx.options |= ssl.OP_NO_TLSv1_1
        sslctx.options |= OpenSSL.SSL.OP_CIPHER_SERVER_PREFERENCE

        cert = '{0}'.format(PropertiesManager().get(csp.P_CERTLOCATION))
        key = '{0}'.format(PropertiesManager().get(csp.P_KEYLOCATION))
        sslctx.load_cert_chain(cert, keyfile=key)
        sslctx.set_ciphers(('ECDHE-RSA-AES256-GCM-SHA384,'
                            'ECDHE-RSA-AES128-GCM-SHA256'))
        global server
        server = HTTPServer(app, ssl_options=sslctx)
        port = PropertiesManager().get(csp.P_PORT)
        server.listen(port)

        global pid
        pid = os.getpid()

        tornado.ioloop.IOLoop.current().start()

def main():
    """
    This is, obviously, the main() function for the CSDASSRV REST service.
    @return:
    """
    rootpath = os.path.join(os.path.dirname(os.path.abspath(__file__)), "../")
    os.chdir(rootpath)
    sys.path.append(os.path.join(os.path.dirname(__file__), "../"))

    error_str = '**** Parameter Required - <start/stop> ****'
    if len(sys.argv) <= 1:
        quit()

    arg = str(sys.argv[1]).lower()
    if arg != 'start' and arg != 'stop':
        quit()

    svc = CSDASSRV()
    if arg == 'start':
        svc.start()
    else:
        svc.shutdown()

if __name__ == '__main__':
    main()
