--
-- PostgreSQL database dump
--

SET statement_timeout = 0;
SET lock_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = on;
SET check_function_bodies = false;
SET client_min_messages = warning;


SET search_path = public, pg_catalog;

SET default_tablespace = '';

SET default_with_oids = false;


CREATE SEQUENCE migration_id_seq
    START WITH 10
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;

CREATE TABLE migration (
    migration_id integer DEFAULT nextval('migration_id_seq'::regclass) NOT NULL,
    filename character varying(64),
    date_completed timestamp without time zone,
    status character varying(16)
);


ALTER TABLE migration OWNER TO cyberpgsql;

ALTER TABLE ONLY migration
    ADD CONSTRAINT migration_pk PRIMARY KEY (migration_id);

--
-- Name: apikeys; Type: TABLE; Schema: public; Owner: cyberpgsql; Tablespace: 
--

CREATE TABLE apikeys (
    apikey_id integer NOT NULL,
    user_id integer,
    public_key text,
    private_key text,
    uuid character varying(64)
);


ALTER TABLE apikeys OWNER TO cyberpgsql;

--
-- Name: apikeys_id_seq; Type: SEQUENCE; Schema: public; Owner: cyberpgsql
--

CREATE SEQUENCE apikeys_id_seq
    START WITH 2
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE apikeys_id_seq OWNER TO cyberpgsql;

--
-- Name: apikeys_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: cyberpgsql
--

ALTER SEQUENCE apikeys_id_seq OWNED BY apikeys.apikey_id;


--
-- Name: event; Type: TABLE; Schema: public; Owner: cyberpgsql; Tablespace: 
--

CREATE TABLE event (
    event_id integer NOT NULL,
    event_type_id integer NOT NULL,
    event_date timestamp(6) without time zone DEFAULT now() NOT NULL,
    user_id integer,
    details text,
    uuid character varying(64)
);


ALTER TABLE event OWNER TO cyberpgsql;

--
-- Name: event_id_seq; Type: SEQUENCE; Schema: public; Owner: cyberpgsql
--

CREATE SEQUENCE event_id_seq
    START WITH 2
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE event_id_seq OWNER TO cyberpgsql;

--
-- Name: event_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: cyberpgsql
--

ALTER SEQUENCE event_id_seq OWNED BY event.event_id;


--
-- Name: eventtype; Type: TABLE; Schema: public; Owner: cyberpgsql; Tablespace: 
--

CREATE TABLE eventtype (
    event_type_id integer NOT NULL,
    event_type_desc character varying(64)
);


ALTER TABLE eventtype OWNER TO cyberpgsql;

--
-- Name: eventtype_id_seq; Type: SEQUENCE; Schema: public; Owner: cyberpgsql
--

CREATE SEQUENCE eventtype_id_seq
    START WITH 2
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE eventtype_id_seq OWNER TO cyberpgsql;

--
-- Name: eventtype_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: cyberpgsql
--

ALTER SEQUENCE eventtype_id_seq OWNED BY eventtype.event_type_id;


--
-- Name: nfa_id_seq; Type: SEQUENCE; Schema: public; Owner: cyberpgsql
--

CREATE SEQUENCE nfa_id_seq
    START WITH 3
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE nfa_id_seq OWNER TO cyberpgsql;

--
-- Name: nfa; Type: TABLE; Schema: public; Owner: cyberpgsql; Tablespace: 
--

CREATE TABLE nfa (
    nfa_id integer DEFAULT nextval('nfa_id_seq'::regclass) NOT NULL,
    service_name character varying(32) NOT NULL,
    service_mask integer,
    available boolean DEFAULT false NOT NULL
);


ALTER TABLE nfa OWNER TO cyberpgsql;

--
-- Name: nfauser_id_seq; Type: SEQUENCE; Schema: public; Owner: cyberpgsql
--

CREATE SEQUENCE nfauser_id_seq
    START WITH 3
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE nfauser_id_seq OWNER TO cyberpgsql;

--
-- Name: nfauser; Type: TABLE; Schema: public; Owner: cyberpgsql; Tablespace: 
--

CREATE TABLE nfauser (
    nfauser_id integer DEFAULT nextval('nfauser_id_seq'::regclass) NOT NULL,
    nfa_id integer,
    uuid character varying(64),
    service_mask integer,
    user_id integer,
    precedence smallint
);


ALTER TABLE nfauser OWNER TO cyberpgsql;

--
-- Name: nfausercfg_id_seq; Type: SEQUENCE; Schema: public; Owner: cyberpgsql
--

CREATE SEQUENCE nfausercfg_id_seq
    START WITH 2
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE nfausercfg_id_seq OWNER TO cyberpgsql;

--
-- Name: nfausercfg; Type: TABLE; Schema: public; Owner: cyberpgsql; Tablespace: 
--

CREATE TABLE nfausercfg (
    nfausercfg_id integer DEFAULT nextval('nfausercfg_id_seq'::regclass) NOT NULL,
    user_id integer NOT NULL,
    email character varying(128),
    phone character varying(20),
    nfa_id integer NOT NULL,
    method character varying(32)
);


ALTER TABLE nfausercfg OWNER TO cyberpgsql;

--
-- Name: token; Type: TABLE; Schema: public; Owner: cyberpgsql; Tablespace: 
--

CREATE TABLE token (
    token_id integer NOT NULL,
    token text,
    token_create timestamp(6) without time zone DEFAULT now(),
    token_expire timestamp(6) without time zone,
    uuid character varying(64)
);


ALTER TABLE token OWNER TO cyberpgsql;

--
-- Name: token_id_seq; Type: SEQUENCE; Schema: public; Owner: cyberpgsql
--

CREATE SEQUENCE token_id_seq
    START WITH 2
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE token_id_seq OWNER TO cyberpgsql;

--
-- Name: token_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: cyberpgsql
--

ALTER SEQUENCE token_id_seq OWNED BY token.token_id;


--
-- Name: userinfo; Type: TABLE; Schema: public; Owner: cyberpgsql; Tablespace: 
--

CREATE TABLE userinfo (
    userinfo_id integer NOT NULL,
    user_id integer NOT NULL,
    domain character varying(64),
    user_type smallint,
    uuid character varying(64),
    scope character varying(32),
    tenant character varying(32),
    create_date timestamp without time zone DEFAULT now()
);


ALTER TABLE userinfo OWNER TO cyberpgsql;

--
-- Name: userinfo_id_seq; Type: SEQUENCE; Schema: public; Owner: cyberpgsql
--

CREATE SEQUENCE userinfo_id_seq
    START WITH 2
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE userinfo_id_seq OWNER TO cyberpgsql;

--
-- Name: userinfo_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: cyberpgsql
--

ALTER SEQUENCE userinfo_id_seq OWNED BY userinfo.userinfo_id;


--
-- Name: users; Type: TABLE; Schema: public; Owner: cyberpgsql; Tablespace: 
--

CREATE TABLE users (
    user_id integer NOT NULL,
    login_id character varying(255) NOT NULL,
    password character varying(255) NOT NULL,
    uuid character varying(64)
);


ALTER TABLE users OWNER TO cyberpgsql;

--
-- Name: users_uid_seq; Type: SEQUENCE; Schema: public; Owner: cyberpgsql
--

CREATE SEQUENCE users_uid_seq
    START WITH 5
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE users_uid_seq OWNER TO cyberpgsql;

--
-- Name: users_uid_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: cyberpgsql
--

ALTER SEQUENCE users_uid_seq OWNED BY users.user_id;


--
-- Name: userstatus; Type: TABLE; Schema: public; Owner: cyberpgsql; Tablespace: 
--

CREATE TABLE userstatus (
    userstatus_id integer NOT NULL,
    user_id integer NOT NULL,
    status integer,
    num_failed smallint,
    last_success timestamp(6) without time zone,
    last_attempt timestamp(6) without time zone,
    locked_until timestamp(6) without time zone,
    uuid character varying(64)
);


ALTER TABLE userstatus OWNER TO cyberpgsql;

--
-- Name: userstatus_id_seq; Type: SEQUENCE; Schema: public; Owner: cyberpgsql
--

CREATE SEQUENCE userstatus_id_seq
    START WITH 3
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE userstatus_id_seq OWNER TO cyberpgsql;

--
-- Name: userstatus_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: cyberpgsql
--

ALTER SEQUENCE userstatus_id_seq OWNED BY userstatus.userstatus_id;


--
-- Name: apikey_id; Type: DEFAULT; Schema: public; Owner: cyberpgsql
--

ALTER TABLE ONLY apikeys ALTER COLUMN apikey_id SET DEFAULT nextval('apikeys_id_seq'::regclass);


--
-- Name: event_id; Type: DEFAULT; Schema: public; Owner: cyberpgsql
--

ALTER TABLE ONLY event ALTER COLUMN event_id SET DEFAULT nextval('event_id_seq'::regclass);


--
-- Name: event_type_id; Type: DEFAULT; Schema: public; Owner: cyberpgsql
--

ALTER TABLE ONLY eventtype ALTER COLUMN event_type_id SET DEFAULT nextval('eventtype_id_seq'::regclass);


--
-- Name: token_id; Type: DEFAULT; Schema: public; Owner: cyberpgsql
--

ALTER TABLE ONLY token ALTER COLUMN token_id SET DEFAULT nextval('token_id_seq'::regclass);


--
-- Name: userinfo_id; Type: DEFAULT; Schema: public; Owner: cyberpgsql
--

ALTER TABLE ONLY userinfo ALTER COLUMN userinfo_id SET DEFAULT nextval('userinfo_id_seq'::regclass);


--
-- Name: user_id; Type: DEFAULT; Schema: public; Owner: cyberpgsql
--

ALTER TABLE ONLY users ALTER COLUMN user_id SET DEFAULT nextval('users_uid_seq'::regclass);


--
-- Name: userstatus_id; Type: DEFAULT; Schema: public; Owner: cyberpgsql
--

ALTER TABLE ONLY userstatus ALTER COLUMN userstatus_id SET DEFAULT nextval('userstatus_id_seq'::regclass);


--
-- Data for Name: apikeys; Type: TABLE DATA; Schema: public; Owner: cyberpgsql
--

INSERT INTO apikeys (apikey_id, user_id, public_key, private_key, uuid) VALUES ('3','216',E'-----BEGIN PUBLIC KEY-----\nMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAsU0tKtGmR2oYDgUoTTCS\nmfYzZnfNFCpFrUWcHIzYLocgkPlcJhU8+cJMpYYZhgO3UFaR9SWRR37hTbSqSsPP\n5Iumuar2AYy4RxTJk9rbTF621h74af3hvbj/90bMgJohhou4k5gg6+1NUI+LXU+U\n+1k40QwAZwnQLuXtl4moSVtOHwCv/equ+poA9lvjkLdEK40Xzbu8c8sNAbsECmIv\nsu15nf4eA5mCgNoMiFHfAMJPkQzaU1wmehPf70LCpYIBaRM1H6JaIrNkeK4ifura\ntNLuoqCTVxihlG0gqB+5zkwbBBRNtgOIDeEbDKgJLaFo1Bm09y4hl06osybDZB01\npwIDAQAB\n-----END PUBLIC KEY-----',E'-----BEGIN RSA PRIVATE KEY-----\nMIIEpAIBAAKCAQEAsU0tKtGmR2oYDgUoTTCSmfYzZnfNFCpFrUWcHIzYLocgkPlc\nJhU8+cJMpYYZhgO3UFaR9SWRR37hTbSqSsPP5Iumuar2AYy4RxTJk9rbTF621h74\naf3hvbj/90bMgJohhou4k5gg6+1NUI+LXU+U+1k40QwAZwnQLuXtl4moSVtOHwCv\n/equ+poA9lvjkLdEK40Xzbu8c8sNAbsECmIvsu15nf4eA5mCgNoMiFHfAMJPkQza\nU1wmehPf70LCpYIBaRM1H6JaIrNkeK4ifuratNLuoqCTVxihlG0gqB+5zkwbBBRN\ntgOIDeEbDKgJLaFo1Bm09y4hl06osybDZB01pwIDAQABAoIBADMF7rWf16Y9leaS\n/WIZVFcSTwByAYaIE70lhyOANMZPBMQzvp0HB6EolT4dNUMn1p08DIzr3r8geF4Q\nW+FgMHeo6LYNyPXxNSbfiJMQLIPxzdQY3YxDD6+1iZPzv+5SbMt3cgqngPHkPJeu\nd4DG4izjJEKknYkJfevBJ3qwlsllDl65226plWy3lpUNSxhOeg9k2bs4uTCtv2NM\nGPya7T0vxnC+gCuDQE3tKmB/jQxosjCZ5MB0uaHX4ac6eEKoF41V+lB5Oxftec1i\nAXvqRSj2Kgx8q/q2niejDEIirXfKdKJuEs8NqQrfNETdiJJalJINttT+LvtoU992\nCl8zWIECgYEAyD1s2MZQN0GJi7h26mxnY/vG/E+JFH8fXj471QPSwmyU1TVPHqAZ\nLoWtIww0swpTrQke6tTxlvDDjRBxOPaFzE6cU3f4R0ERTo72XxfMTI0rIwb2b6TS\nsOtRUPqd7U7qMy/VQNIazqlkSJpymT3uNBgeikX83qoMMFY8O+M7NpECgYEA4qyH\nRPCgVJAcvPTenmS9FbImhQqEQW2ZfjW9dLsJkKxoHw3IA94pPd3/yfij2ywpDEeW\nxiTBZ26Uhlqb5sipbqLw1RReZIZo/48aNxQ260fqbbJEw8QL8QKR9Um6RVMGTfIS\nWVJyah1pjx6f482PYtJtm7J7UeP8D0BG3CHX9LcCgYB8iXeA+xY4x5H8TCXpdrJ3\nBMilc/IVxVqFCr+7pD0Ynt+SGy2yJnCC9rDP829zSyDvpZSNCROYhPWabnd8rhZZ\nEys23o6UAmv5KAEi83Ikykfh6RqsJR7E2hYg/z3psgMHAuDnB8WUctXkMerEVDgq\nPjYAWbcD5U7fYULlHFZfgQKBgQCaRATDfGgBZRrJ1nTzo2e0Lkxc2u1rgeWmqXhI\ny0oVNeCe0chAKaAzxLRihl8tuH4vJ0GLlFQzymQ2k8/qXsJA04/H1FbxXzByTLfw\nqEdAFO+MvHhkKzZdTfx7zTOCHqD5xzeJprzLTz0Z9COo66sb/E4wWmXnM5vF3V7c\nTgQlPQKBgQCuDooO8A9aPzzlVpDlvRdDM4b+mjGBUukczq4Dv+AUhMxbsSWjm3gf\n2nIK9XCVYnmiTWi+k0pcNUkE23JkvBaDmSydFH0ZJWdEGRhz36r9Hgfkb+x6cvy5\nMe71cASaH8JSBN1YKtGwdUzTamZQnmDDHWufNsDq0oCwp2oEmROYsw==\n-----END RSA PRIVATE KEY-----','6f3626c1-0da7-4b44-8d5e-43750f780a47');


--
-- Name: apikeys_id_seq; Type: SEQUENCE SET; Schema: public; Owner: cyberpgsql
--

SELECT pg_catalog.setval('apikeys_id_seq', 3, true);


--
-- Data for Name: event; Type: TABLE DATA; Schema: public; Owner: cyberpgsql
--



--
-- Name: event_id_seq; Type: SEQUENCE SET; Schema: public; Owner: cyberpgsql
--

SELECT pg_catalog.setval('event_id_seq', 2, true);


--
-- Data for Name: eventtype; Type: TABLE DATA; Schema: public; Owner: cyberpgsql
--



--
-- Name: eventtype_id_seq; Type: SEQUENCE SET; Schema: public; Owner: cyberpgsql
--

SELECT pg_catalog.setval('eventtype_id_seq', 2, true);


--
-- Data for Name: nfa; Type: TABLE DATA; Schema: public; Owner: cyberpgsql
--

INSERT INTO nfa (nfa_id, service_name, service_mask, available) VALUES ('7', 'auth', '0', 't');
INSERT INTO nfa (nfa_id, service_name, service_mask, available) VALUES ('8', 'Telesign', '1', 't');
INSERT INTO nfa (nfa_id, service_name, service_mask, available) VALUES ('9', 'GoogleAuthenticator', '2', 't');


--
-- Name: nfa_id_seq; Type: SEQUENCE SET; Schema: public; Owner: cyberpgsql
--

SELECT pg_catalog.setval('nfa_id_seq', 11, true);


--
-- Data for Name: nfauser; Type: TABLE DATA; Schema: public; Owner: cyberpgsql
--

INSERT INTO nfauser (nfauser_id, nfa_id, uuid, service_mask, user_id, precedence) VALUES ('125', '7', 'ce5a842b-fbbc-4c6e-8d35-a0438fcdf80c', '0', '215', '1');


--
-- Name: nfauser_id_seq; Type: SEQUENCE SET; Schema: public; Owner: cyberpgsql
--

SELECT pg_catalog.setval('nfauser_id_seq', 136, true);


--
-- Data for Name: nfausercfg; Type: TABLE DATA; Schema: public; Owner: cyberpgsql
--


INSERT INTO nfausercfg (nfausercfg_id, user_id, email, phone, nfa_id, method) VALUES ('61', '206', NULL, '123-456-7890', '8', 'SMS');
INSERT INTO nfausercfg (nfausercfg_id, user_id, email, phone, nfa_id, method) VALUES ('62', '206', NULL, NULL, '9', 'MobileApp');
-- INSERT INTO nfausercfg (nfausercfg_id, user_id, email, phone, nfa_id, method) VALUES ('63', '206', NULL, NULL, '10', 'token');
-- INSERT INTO nfausercfg (nfausercfg_id, user_id, email, phone, nfa_id, method) VALUES ('64', '206', 'david@wootan.us', NULL, '11', 'email');
INSERT INTO nfausercfg (nfausercfg_id, user_id, email, phone, nfa_id, method) VALUES ('65', '207', NULL, '123-456-7890', '8', 'SMS');
INSERT INTO nfausercfg (nfausercfg_id, user_id, email, phone, nfa_id, method) VALUES ('66', '207', NULL, NULL, '9', 'MobileApp');


--
-- Name: nfausercfg_id_seq; Type: SEQUENCE SET; Schema: public; Owner: cyberpgsql
--

SELECT pg_catalog.setval('nfausercfg_id_seq', 66, true);

--
-- Data for Name: userinfo; Type: TABLE DATA; Schema: public; Owner: cyberpgsql
--

INSERT INTO userinfo (userinfo_id, user_id, domain, user_type, uuid, scope, tenant, create_date) VALUES ('55', '215', 'cybersponse.com', '2', 'ce5a842b-fbbc-4c6e-8d35-a0438fcdf80c', NULL, 'Venom', '2015-11-11 22:28:10.075825');
INSERT INTO userinfo (userinfo_id, user_id, domain, user_type, uuid, scope, tenant, create_date) VALUES ('56','216','cybersponse.com','3','6f3626c1-0da7-4b44-8d5e-43750f780a47', NULL,'exo-ui','2015-11-11 22:28:10.075825');

--
-- Name: userinfo_id_seq; Type: SEQUENCE SET; Schema: public; Owner: cyberpgsql
--

SELECT pg_catalog.setval('userinfo_id_seq', 66, true);


--
-- Data for Name: users; Type: TABLE DATA; Schema: public; Owner: cyberpgsql
--

INSERT INTO users (user_id, login_id, password, uuid) VALUES ('215', 'csadmin', '$2a$12$zdwwqpen9B5wFrtEAEyc2uJT8HxZDPFLwlNL1W8cfUWxS.f3OeydO', 'ce5a842b-fbbc-4c6e-8d35-a0438fcdf80c');
INSERT INTO users (user_id, login_id, password, uuid) VALUES ('216', '6f3626c1-0da7-4b44-8d5e-43750f780a47', '', '6f3626c1-0da7-4b44-8d5e-43750f780a47');

--
-- Name: users_uid_seq; Type: SEQUENCE SET; Schema: public; Owner: cyberpgsql
--

SELECT pg_catalog.setval('users_uid_seq', 226, true);


--
-- Data for Name: userstatus; Type: TABLE DATA; Schema: public; Owner: cyberpgsql
--

INSERT INTO userstatus (userstatus_id, user_id, status, num_failed, last_success, last_attempt, locked_until, uuid) VALUES ('52', '215', '1', '0', NULL, NULL, NULL, 'ce5a842b-fbbc-4c6e-8d35-a0438fcdf80c');
INSERT INTO userstatus (userstatus_id, user_id, status, num_failed, last_success, last_attempt, locked_until, uuid) VALUES ('53','216', '1','0',NULL,NULL,NULL,'6f3626c1-0da7-4b44-8d5e-43750f780a47');
--
-- Name: userstatus_id_seq; Type: SEQUENCE SET; Schema: public; Owner: cyberpgsql
--

SELECT pg_catalog.setval('userstatus_id_seq', 63, true);


--
-- Name: event_pkey; Type: CONSTRAINT; Schema: public; Owner: cyberpgsql; Tablespace: 
--

ALTER TABLE ONLY event
    ADD CONSTRAINT event_pkey PRIMARY KEY (event_id);


--
-- Name: eventtype_pkey; Type: CONSTRAINT; Schema: public; Owner: cyberpgsql; Tablespace: 
--

ALTER TABLE ONLY eventtype
    ADD CONSTRAINT eventtype_pkey PRIMARY KEY (event_type_id);


--
-- Name: nfa_pkey; Type: CONSTRAINT; Schema: public; Owner: cyberpgsql; Tablespace: 
--

ALTER TABLE ONLY nfa
    ADD CONSTRAINT nfa_pkey PRIMARY KEY (nfa_id);


--
-- Name: nfauser_pk; Type: CONSTRAINT; Schema: public; Owner: cyberpgsql; Tablespace: 
--

ALTER TABLE ONLY nfauser
    ADD CONSTRAINT nfauser_pk PRIMARY KEY (nfauser_id);


--
-- Name: nfausercfg_pk; Type: CONSTRAINT; Schema: public; Owner: cyberpgsql; Tablespace: 
--

ALTER TABLE ONLY nfausercfg
    ADD CONSTRAINT nfausercfg_pk PRIMARY KEY (nfausercfg_id);


--
-- Name: token_pkey; Type: CONSTRAINT; Schema: public; Owner: cyberpgsql; Tablespace: 
--

ALTER TABLE ONLY token
    ADD CONSTRAINT token_pkey PRIMARY KEY (token_id);


--
-- Name: userinfo_pkey; Type: CONSTRAINT; Schema: public; Owner: cyberpgsql; Tablespace: 
--

ALTER TABLE ONLY userinfo
    ADD CONSTRAINT userinfo_pkey PRIMARY KEY (userinfo_id);


--
-- Name: users_login_id_key; Type: CONSTRAINT; Schema: public; Owner: cyberpgsql; Tablespace: 
--

ALTER TABLE ONLY users
    ADD CONSTRAINT users_login_id_key UNIQUE (login_id);


--
-- Name: users_pkey; Type: CONSTRAINT; Schema: public; Owner: cyberpgsql; Tablespace: 
--

ALTER TABLE ONLY users
    ADD CONSTRAINT users_pkey PRIMARY KEY (user_id);


--
-- Name: userstatus_pkey; Type: CONSTRAINT; Schema: public; Owner: cyberpgsql; Tablespace: 
--

ALTER TABLE ONLY userstatus
    ADD CONSTRAINT userstatus_pkey PRIMARY KEY (userstatus_id);


--
-- Name: apikeys_uuid_idx; Type: INDEX; Schema: public; Owner: cyberpgsql; Tablespace: 
--

CREATE INDEX apikeys_uuid_idx ON apikeys USING btree (uuid);


--
-- Name: event_date_idx; Type: INDEX; Schema: public; Owner: cyberpgsql; Tablespace: 
--

CREATE INDEX event_date_idx ON event USING btree (event_date);


--
-- Name: event_type_idx; Type: INDEX; Schema: public; Owner: cyberpgsql; Tablespace: 
--

CREATE UNIQUE INDEX event_type_idx ON event USING btree (event_type_id);


--
-- Name: event_uuid_idx; Type: INDEX; Schema: public; Owner: cyberpgsql; Tablespace: 
--

CREATE INDEX event_uuid_idx ON event USING btree (uuid);


--
-- Name: eventuser_id_idx; Type: INDEX; Schema: public; Owner: cyberpgsql; Tablespace: 
--

CREATE INDEX eventuser_id_idx ON event USING btree (user_id);


--
-- Name: fki_nfauser_user_id_fk; Type: INDEX; Schema: public; Owner: cyberpgsql; Tablespace: 
--

CREATE INDEX fki_nfauser_user_id_fk ON nfauser USING btree (user_id);


--
-- Name: fki_nfausercfg_nfa_id_idx; Type: INDEX; Schema: public; Owner: cyberpgsql; Tablespace: 
--

CREATE INDEX fki_nfausercfg_nfa_id_idx ON nfausercfg USING btree (nfa_id);


--
-- Name: fki_userinfo_userid_fkey; Type: INDEX; Schema: public; Owner: cyberpgsql; Tablespace: 
--

CREATE INDEX fki_userinfo_userid_fkey ON token USING btree (uuid);


--
-- Name: index_user_id_idx; Type: INDEX; Schema: public; Owner: cyberpgsql; Tablespace: 
--

CREATE INDEX index_user_id_idx ON userstatus USING btree (user_id);


--
-- Name: login_idx; Type: INDEX; Schema: public; Owner: cyberpgsql; Tablespace: 
--

CREATE UNIQUE INDEX login_idx ON users USING btree (login_id);


--
-- Name: nfauser_uuid_idx; Type: INDEX; Schema: public; Owner: cyberpgsql; Tablespace: 
--

CREATE INDEX nfauser_uuid_idx ON nfauser USING btree (uuid);


--
-- Name: token_expire_idx; Type: INDEX; Schema: public; Owner: cyberpgsql; Tablespace: 
--

CREATE INDEX token_expire_idx ON token USING btree (token_expire);


--
-- Name: token_uuid_idx; Type: INDEX; Schema: public; Owner: cyberpgsql; Tablespace: 
--

CREATE INDEX token_uuid_idx ON token USING btree (uuid);


--
-- Name: ui_uuid_idx; Type: INDEX; Schema: public; Owner: cyberpgsql; Tablespace: 
--

CREATE UNIQUE INDEX ui_uuid_idx ON userinfo USING btree (uuid);


--
-- Name: user_id_idx; Type: INDEX; Schema: public; Owner: cyberpgsql; Tablespace: 
--

CREATE UNIQUE INDEX user_id_idx ON apikeys USING btree (user_id);


--
-- Name: user_ui_idx; Type: INDEX; Schema: public; Owner: cyberpgsql; Tablespace: 
--

CREATE UNIQUE INDEX user_ui_idx ON userinfo USING btree (user_id);


--
-- Name: userstatus_status_idx; Type: INDEX; Schema: public; Owner: cyberpgsql; Tablespace: 
--

CREATE INDEX userstatus_status_idx ON userstatus USING btree (status);


--
-- Name: User.fk; Type: FK CONSTRAINT; Schema: public; Owner: cyberpgsql
--

ALTER TABLE ONLY userstatus
    ADD CONSTRAINT "User.fk" FOREIGN KEY (user_id) REFERENCES users(user_id);


--
-- Name: User_fk; Type: FK CONSTRAINT; Schema: public; Owner: cyberpgsql
--

ALTER TABLE ONLY userinfo
    ADD CONSTRAINT "User_fk" FOREIGN KEY (user_id) REFERENCES users(user_id);


--
-- Name: apikeys_user_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: cyberpgsql
--

ALTER TABLE ONLY apikeys
    ADD CONSTRAINT apikeys_user_id_fkey FOREIGN KEY (user_id) REFERENCES users(user_id);


--
-- Name: apikeys_uuid_fkey; Type: FK CONSTRAINT; Schema: public; Owner: cyberpgsql
--

ALTER TABLE ONLY apikeys
    ADD CONSTRAINT apikeys_uuid_fkey FOREIGN KEY (uuid) REFERENCES userinfo(uuid);


--
-- Name: event_event_type_fkey; Type: FK CONSTRAINT; Schema: public; Owner: cyberpgsql
--

ALTER TABLE ONLY event
    ADD CONSTRAINT event_event_type_fkey FOREIGN KEY (event_type_id) REFERENCES eventtype(event_type_id);


--
-- Name: event_user_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: cyberpgsql
--

ALTER TABLE ONLY event
    ADD CONSTRAINT event_user_id_fkey FOREIGN KEY (user_id) REFERENCES users(user_id);


--
-- Name: event_uuid_fkey; Type: FK CONSTRAINT; Schema: public; Owner: cyberpgsql
--

ALTER TABLE ONLY event
    ADD CONSTRAINT event_uuid_fkey FOREIGN KEY (uuid) REFERENCES userinfo(uuid);


--
-- Name: nfausercfg_nfa_id_idx; Type: FK CONSTRAINT; Schema: public; Owner: cyberpgsql
--

ALTER TABLE ONLY nfausercfg
    ADD CONSTRAINT nfausercfg_nfa_id_idx FOREIGN KEY (nfa_id) REFERENCES nfa(nfa_id);


--
-- Name: userinfo_userid_fkey; Type: FK CONSTRAINT; Schema: public; Owner: cyberpgsql
--

ALTER TABLE ONLY token
    ADD CONSTRAINT userinfo_userid_fkey FOREIGN KEY (uuid) REFERENCES userinfo(uuid);


--
-- Name: userstatus_user_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: cyberpgsql
--

ALTER TABLE ONLY userstatus
    ADD CONSTRAINT userstatus_user_id_fkey FOREIGN KEY (user_id) REFERENCES users(user_id);


--
-- Name: public; Type: ACL; Schema: -; Owner: postgres
--

REVOKE ALL ON SCHEMA public FROM PUBLIC;
REVOKE ALL ON SCHEMA public FROM postgres;
GRANT ALL ON SCHEMA public TO postgres;
GRANT ALL ON SCHEMA public TO PUBLIC;


--
-- PostgreSQL database dump complete
--
