from sqlalchemy.orm import mapper
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy import Column, Integer, String, Table, MetaData, DateTime

import os
import sys
from datetime import datetime
from utilities.cssessionmanager import CSSessionManager
from utilities.csconstants import CSConstants

Base = declarative_base()


class DASMigrate():
    __tablename__ = CSConstants.CS_TABLE_MIGRATION
    metadata = MetaData()

    table_dmigrate = Table(__tablename__, metadata,
                           Column('migration_id', Integer, primary_key=True),
                           Column('filename', String),
                           Column('date_completed', DateTime),
                           Column('status', Integer)
                           )

    class DMigrate(object):
        def __init__(self, migration_id=None, filename=None, date_completed=None, status=None):
            self.migration_id = migration_id
            self.filename = filename
            self.date_completed = date_completed
            self.status = status

    mapper(DMigrate, table_dmigrate)

    def up(self):
        return self.__read('up')

    def down(self):
        return self.__read('down')

    @staticmethod
    def __parse_datadata(data):
        datalist = data.split(';')
        return datalist

    @staticmethod
    def __migrate_file_is_available(file):
        sm = CSSessionManager()
        with sm:
            tablemigrate = DASMigrate()
            counter = sm.session.query(tablemigrate.DMigrate).filter_by(filename=file).count()
            return counter > 0

    def __read(self, direction):
        assert isinstance(direction, str)
        location = './sql/migration/' if direction == 'up' else './sql/rollback/'
        dirlist = sorted(os.listdir(location))
        sm = CSSessionManager()

        with sm:
            for file in dirlist:
                if file.endswith(".sql"):
                    resp = self.__migrate_file_is_available(file)

                    if True is resp:
                        if direction is CSConstants.CS_UP:
                            continue
                    elif False is resp:
                        if direction is CSConstants.CS_DOWN:
                            continue

                    datalist = DASMigrate().__parse_datadata(open(location + file).read())
                    for cmd in datalist:
                        sm.session.execute(cmd)
                        sm.session.commit()

                    tablemigrate = self.DMigrate()

                    if direction == CSConstants.CS_UP:
                        tablemigrate.filename = file
                        tablemigrate.date_completed = datetime.utcnow()
                        tablemigrate.status = CSConstants.CS_SUCCESS
                        sm.session.add(tablemigrate)
                        sm.session.commit()
                    else:
                        deletestmt = "delete from migration where filename = '{0}'".format(file)
                        sm.session.execute(deletestmt)
                        sm.session.commit()

                    print('**** {0} ****'.format(CSConstants.CS_SUCCESS))


def main():
    if len(sys.argv) <= 1:
        print('**** parameter required ****')
        quit()

    direction = str(sys.argv[1].lower())
    das = DASMigrate()
    if 'up' == direction.lower():
        das.up()
    else:
        das.down()

if __name__ == '__main__':
    main()
