from time import sleep
from subprocess import Popen, PIPE
import threading
import sys
import schedule

from sqlalchemy.exc import DBAPIError

sys.path.append("/opt/cyops-auth")
from handlerworkers import cluster
from utilities.csconstants import CSConstants
from log.cslog import get_ha_logger
from utilities.ha.services import get_cyops_services_list, execute_cmd
from utilities.ha import handler
logger = get_ha_logger(__name__)

def run_cluster_command(commandId, command, status):
    if command:
        try:
            cluster.mark_command_in_progress(commandId)
            command_result = Popen(command, shell=True, stdout=PIPE, stderr=PIPE)
            output, error = command_result.communicate()
            returncode = command_result.returncode
            if returncode == 0:
                if status == CSConstants.CS_COMMAND_TODO_SYNC:
                    cluster.mark_command_complete(commandId, output.decode('utf-8'))
                else:
                    cluster.dismiss_command(commandId)
            else:
                logger.warn('Command failed with error: '+error.decode('utf-8'))
                cluster.mark_command_failed(commandId, error.decode('utf-8'))
        except Exception as e:
            logger.exception('Error executing command: %s' % command)
            cluster.mark_command_failed(commandId, str(e))


if __name__ == '__main__':
    # ensure that the node is not faulted
    current_node = cluster.get_current_node()
    while not current_node:
        # Case when the node has not yet joined self cluster
        logger.warn("Node is not part of any cluster")
        sleep(20)
        current_node = cluster.get_current_node()
    status = current_node['status']
    if status.lower() == 'faulted':
        logger.error('Node status is faulted. Wait for 2 mins for boot and disable all services.')
        sleep(120)
        serv_list = get_cyops_services_list()
        for serv in serv_list:
            # do not kill self
            if serv.strip() != 'cyops-ha':
                cmd = "systemctl stop " + serv
                execute_cmd(cmd)
                cmd = "systemctl disable " + serv
                execute_cmd(cmd)
                cmd = "systemctl mask " + serv
                execute_cmd(cmd)
        # only ha service keeps running forever
        while True:
            sleep(120)
    else:
        handler.schedule_health_check()
        # create a subprocess for publish_messages listener
        Popen(['/opt/cyops-auth/utilities/ha/cluster_publish.py'])
        while True:
            schedule.run_pending()
            try:
                pending_commands = cluster.get_self_cluster_command()
                for pending_command in pending_commands:
                    # run the command in a separate thread
                    commandId = pending_command.id
                    command = pending_command.command
                    status = pending_command.status
                    logger.info('Executing command ' + command)
                    t = threading.Thread(target=run_cluster_command, args=(commandId, command, status))
                    t.daemon = True
                    # TODO: validate that the thread exits once the command completes
                    t.start()
            except DBAPIError as db_error:
                logger.warn("HA service failed to connect to Database")
            except Exception as e:
                logger.exception("Error fetching cluster command")
            # sleep for 10 seconnds
            sleep(10)
