#!/opt/cyops-auth/.env/bin/python
import os
import sys
import argparse

if not os.geteuid() == 0:
    sys.exit("You need to be root to perform this command.")

sys.path.append("/opt/cyops-auth")
from handlerworkers.license import CSLicenseManager, NODE_HARDWARE_KEY

def take_arguments():
    print ("1. Get Hardware Key")
    print ("2. Deploy License File")
    print ("Press Ctrl+C to exit")

    option = input("Select an option: ")
    if not option:
        print ("Please provide an input")
        take_arguments()
    else :
        try:
            option = int(option)
            if option != 1 and option != 2:
                print(option)
                print("Wrong option selected. Please Try again")
                sys.exit()
        except ValueError as error:
            print("Invalid input argument provided. Please try again\n")
            take_arguments()

    if option == 1:
        print("Hardware Key: " + NODE_HARDWARE_KEY)

    elif option == 2:
        while True:
            option = input("Is the license issued for distributed multi-tenancy setup(y/n/yes/no)? ").lower().strip()
            if option == 'y' or option == 'yes':
                is_distributed = True
                break
            elif option == 'n' or option == 'no':
                is_distributed = False
                break
            else:
                print("Please provide valid input(y/n/yes/no)")
        file_path = input("License file path: ")
        deploy_license(file_path, is_distributed)

def is_valid_file(file):
    if not os.path.exists(file):
        raise argparse.ArgumentTypeError("File {0} does not exist".format(file))
    return file

def start():
    parser = argparse.ArgumentParser()
    group = parser.add_mutually_exclusive_group()
    group.add_argument('--get-hkey', dest='get_hkey', action='store_true', help='Retrieve hardware key for this machine')
    group.add_argument('--deploy-enterprise-license', dest="enterprise_license", help='Deploy enterprise license', type=is_valid_file)
    group.add_argument('--deploy-multi-tenant-license', dest="distributed_license", help='Deploy multi-tenant license', type=is_valid_file)
    args = parser.parse_args()
    if args.get_hkey:
        print(NODE_HARDWARE_KEY)
        return
    if args.distributed_license:
        deploy_license(args.distributed_license, True)
        return
    if args.enterprise_license:
        deploy_license(args.enterprise_license, False)
        return

    print("Command to either generate hardware key or to a deploy license\n")
    try:
        take_arguments()
    except KeyboardInterrupt:
        print("")



def deploy_license(license_file, is_distributed):
    try:
        with open(license_file) as license_file:
            license_key = license_file.read()
            deployment_status, message = CSLicenseManager().deploy_license(license_key, is_distributed)
            if deployment_status is True:
                print("License deployed successfully")
            else:
                print(message)
    except FileNotFoundError as error:
        print("The file "+license_file+ " not found. Please try again")


if __name__ == "__main__":
    start()
